<?php
include('config.php');

// Check if animeid is provided in the URL
$animeid = isset($_GET['animeid']) ? $_GET['animeid'] : null;

if (empty($animeid)) {
    echo "No anime id provided.";
    exit; // Stop further execution if no anime id is provided
}

// API URL (example)
$apiUrl = "$apiBase/api/details/" . urlencode($animeid)."?api_key=$apiKey";

// Fetch data from API
$response = file_get_contents($apiUrl);

if ($response === false) {
    echo "Failed to fetch data from API.";
    exit;
}

$data = json_decode($response, true);

if (empty($data) || isset($data['message']) && $data['message'] === 'No anime found') {
    echo "No anime found.";
    exit;
}

function unslug($animeid) {
    // Replace hyphens with spaces
    $unanimeid = str_replace('-', ' ', $animeid);
    // Capitalize the first letter of each word
    $unanimeid = ucwords($unanimeid);
	return $unanimeid;
}
?>


<!DOCTYPE html>
<html lang="en-US" prefix="og: http://ogp.me/ns#">
<head style="background-color: #121212;" itemscope itemtype="http://schema.org/WebSite">
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<title>Watch <?php echo unslug($animeid);?> Online Episode List - <?php echo $Title; ?></title>
<meta name="description" content="Watch <?php echo $data['title'];?>  online at <?php echo $Title; ?>" />
<link rel="canonical" href="/anime/<?php echo $id; ?>" />
<meta property='og:type' content='website' />
<meta property='og:url' content='/anime/<?php echo $id; ?>' />
<meta property='og:title' content="Watch <?php echo unslug($animeid);?> Online Sub Episode List - <?php echo $Title; ?>" />
<meta property='og:description' content="Watch <?php echo unslug($animeid);?> online subbed at <?php echo $Title; ?>" />
<meta http-equiv='Content-Type' content='text/html; charset=UTF-8'>
<link rel='shortcut icon' href='/favicon.ico?v=<?php echo $v; ?>' type='image/x-icon'>
<link rel='icon' href='/favicon.ico?v=<?php echo $v; ?>' type='image/x-icon'>
<meta property='og:image' content='/img/logo.png?v=<?php echo $v; ?>' />
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="msapplication-TileColor" content="#201f1f" />
<meta name="theme-color" content="#201f1f" />
<link rel="stylesheet" href="/css/style.css?v=<?php echo $v; ?>">
<link href="https://fonts.googleapis.com/css?family=Cabin:400,400i,500,500i,600,600i,700,700i&display=swap" rel="stylesheet" />
<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.9.0/css/all.css" integrity="sha384-i1LQnF23gykqWXg6jxC2ZbCbUMxyw5gLZY6UiUS98LYV5unm8GWmfkIS6jqJfb4E" crossorigin="anonymous" />
<script src="/js/jquery-1.12.4.min.js?v=<?php echo $v; ?>"></script>
<script src="/js/script-js.js?v=<?php echo $v; ?>"></script>
<?php echo $GoogleAnalytics; ?>
</head>
<body>

<div class="main-container">
<header id="hd" class="hd" itemscope="" itemtype="http://schema.org/WPHeader">
<div class="cent">
<button type="button" class="bta btaa">
<i>
</i>
</button>
<figure class="logo fg1">
<div itemscope="itemscope" itemtype="http://schema.org/Brand" class="d-flex">
<a itemprop="url" href="/">
<img itemprop="logo" src="/img/logo.png?v=<?php echo $v; ?>" title="<?php echo $Title; ?> - Stream Anime Sub or Dub in High Quality up to 1080p" alt="<?php echo $Title; ?> - Stream Anime Sub or Dub in High Quality up to 1080p">
</a>
<div class="menu-header-alt cny">
<?php include('menu.php'); ?>
</nav>
</div>
</header>
	
<div class="desktop-view" id="details">
    <div class="top-detail relative">
        <span class="background-gradient"></span>
        <img class="details-bg" src="https://cdn.okarun.ws<?php echo $data['image']; ?>" alt="banner image">
        <div class="uk-width-expand relative z-10">
            <div class="uk-container uk-container-large py-8">
                <img class="mt-3" src="https://cdn.okarun.ws<?php echo $data['image']; ?>" alt="<?php echo $data['title']; ?>">
            </div>
            <div class="info py-8 mt-3">
                <h1 class="mb-1 text-3xl uppercase font-black">
                    <div><?php echo $data['title']; ?></div>
                </h1>
                <ul class="list-reset font-bold flex items-center uppercase mb-8">
                    <li class="inline"><?php echo $data['titlejp']; ?></li>
                </ul>
                <ul class="list-reset font-bold flex items-center uppercase mb-8">
                    <li class="inline"><?php echo $data['type']; ?> | <?php echo $data['episodes_count']; ?> Episodes</li>
                </ul>
                <ul class="list-reset font-bold flex items-center uppercase mb-8">
                    <li class="inline"><?php echo $data['description']; ?></li>
                </ul>
				
				<ul class="list-reset font-bold flex items-center uppercase mb-8">
                    <li class="inline">Studio : <?php echo $data['studios']; ?></li>
					<li class="inline">Release : <?php echo $data['date_aired']; ?></li>
					<li class="inline">Duration : <?php echo $data['duration']; ?></li>
					<li class="inline">Status : <?php echo $data['status']; ?></li>
                </ul>
				<ul class="list-reset font-bold flex items-center uppercase mb-8">
					<li class="inline">Genres : <?php
									$genres = array_map('trim', explode(",", $data['genre'])); // Trim each genre after splitting
									$genreLinks = [];

									foreach ($genres as $genre) {
										$gslug = strtolower(str_replace(" ", "-", $genre)); // Convert to slug format
										$genreLinks[] = htmlspecialchars($genre);
									}

									echo implode(", ", $genreLinks); // Join genres with ", " without extra spaces
									?></li>
				</ul>

				
            </div>
        </div>
    </div>

    <div class="details-content">
        <div class="uk-container uk-container-large py-8 text-md">
            <div class="costr foregrounda">
                <span class="name">Episodes</span>
                <span class="line"></span>
            </div>
            <ul class="episode">
                <?php
				// Fetch API details for the anime 
				$anime_episodes_url = "$apiBase/api/episodes/$animeid?api_key=$apiKey";

				// Function to fetch data from the API
				function fetchAPI($url) {
					$ch = curl_init();
					curl_setopt($ch, CURLOPT_URL, $url);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
					curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
					$response = curl_exec($ch);
					curl_close($ch);
					return json_decode($response, true);
				}

				// Get anime details and episodes
				$anime_episodes = fetchAPI($anime_episodes_url);

				?>
					<?php foreach ($anime_episodes as $episode): ?>
                    <li class="epi-me">
                        <a href="/watch/<?= $episode['animeid'] ?>-episode-<?= $episode['epnum'] ?>">
                            <div title="Episode <?= $episode['epnum'] ?>" class="name">
                                <span>EP <?= $episode['epnum'] ?></span>
                            </div>
                            <div class="vien"></div>
                            <div class="cate"><?= $data['type'] ?></div>
                        </a>
                    </li>
					<?php endforeach; ?>
                
            </ul>
            <a href="https://codyphp.com" target="_blank" rel="noopener noreferrer">
                <img src="https://i.ibb.co/KFHbyKC/Looking-for-Streaming-Script.gif" alt="Anime Streaming Script">
            </a>
            <div class="costr foregrounda">
                <span class="name">Comments</span>
                <span class="line"></span>
            </div>
			<div id="disqus_thread"></div>
			<script>
				 var site_config = {
				'domain': '<?php echo $DisqusDomain; ?>',
				'disqus': '<?php echo $DisqusShort; ?>', // Make sure this matches your Disqus shortname
				};

				// Dynamically load Disqus
				(function() {
					var d = document, s = d.createElement('script');
					s.src = 'https://' + site_config.disqus + '.disqus.com/embed.js';
					s.setAttribute('data-timestamp', +new Date());
					(d.head || d.body).appendChild(s);
				})();

			</script>
        </div>
    </div>
</div>

<footer class="ft">
<div class="cont">
<nav>
<?php include('footurl.php'); ?>
<p class="copy tac">Copyright © <?php echo $Title; ?>. All Rights Reserved
</p>
</nav>
</div>
</footer>
</div>
</body>
</html>