<?php
include('config.php');

// Check if animeid is provided in the URL
$animeid = isset($_GET['animeid']) ? $_GET['animeid'] : null;
$episode = isset($_GET['episode']) ? $_GET['episode'] : 1;

if (empty($animeid)) {
    echo "No anime id provided.";
    exit; // Stop further execution if no anime id is provided
}

// API URL (example)
$apiUrl = "$apiBase/api/details/" . urlencode($animeid)."?api_key=$apiKey";

// Fetch data from API
$response = file_get_contents($apiUrl);

if ($response === false) {
    echo "Failed to fetch data from API.";
    exit;
}

$data = json_decode($response, true);

if (empty($data) || isset($data['message']) && $data['message'] === 'No anime found') {
    echo "No anime found.";
    exit;
}

function unslug($animeid) {
    // Replace hyphens with spaces
    $unanimeid = str_replace('-', ' ', $animeid);
    // Capitalize the first letter of each word
    $unanimeid = ucwords($unanimeid);
	return $unanimeid;
}

function slugify($text)
{
    // replace non letter or digits by -
    $text = preg_replace('~[^\pL\d]+~u', '-', $text);

    // transliterate
    $text = iconv('utf-8', 'us-ascii//TRANSLIT', $text);

    // remove unwanted characters
    $text = preg_replace('~[^-\w]+~', '', $text);

    // trim
    $text = trim($text, '-');

    // remove duplicate -
    $text = preg_replace('~-+~', '-', $text);

    // lowercase
    $text = strtolower($text);

    if (empty($text)) {
        return 'n-a';
    }

    return $text;
}
?>
<!DOCTYPE html>
<html lang="en-US" prefix="og: http://ogp.me/ns#">
<head style="background-color: #121212;" itemscope itemtype="http://schema.org/WebSite">
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<title>Watch <?php echo unslug($animeid);?> Episode <?php echo $episode;?> on <?php echo $Title; ?></title>
<meta name="description" content="<?php echo unslug($animeid);?> Episode <?php echo $episode;?> here using any of the servers available." />
<link rel="canonical" href="/watch/<?php echo $animeid; ?>-episode-<?php echo $episode; ?>"/>
<link rel="alternate" hreflang="en-us" href="/watch/<?php echo $animeid; ?>-episode-<?php echo $episode; ?>"/>
<meta property='og:type' content='watch' />
<meta property='og:url' content='/watch/<?php echo $animeid; ?>-episode-<?php echo $episode; ?>' />
<meta property='og:title' content="Stream <?php echo unslug($animeid);?> Episode <?php echo $episode;?> online at <?php echo $Title; ?>" />
<meta property='og:description' content="Watch <?php echo unslug($animeid);?> Episode <?php echo $episode;?> here using any of the servers available." />
<meta http-equiv='Content-Type' content='text/html; charset=UTF-8'>
<link rel='shortcut icon' href='/favicon.ico?v=<?php echo $v; ?>' type='image/x-icon'>
<link rel='icon' href='/favicon.ico?v=<?php echo $v; ?>' type='image/x-icon'>
<meta property='og:image' content='/img/logo.png?v=<?php echo $v; ?>' />
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="msapplication-TileColor" content="#201f1f" />
<meta name="theme-color" content="#201f1f" />
<link rel="stylesheet" href="/css/style.css?v=<?php echo $v; ?>">
<link href="https://fonts.googleapis.com/css?family=Cabin:400,400i,500,500i,600,600i,700,700i&display=swap" rel="stylesheet" />
<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.9.0/css/all.css" integrity="sha384-i1LQnF23gykqWXg6jxC2ZbCbUMxyw5gLZY6UiUS98LYV5unm8GWmfkIS6jqJfb4E" crossorigin="anonymous" />
<script src="/js/jquery-1.12.4.min.js?v=<?php echo $v; ?>"></script>
<script src="/js/script-js.js?v=<?php echo $v; ?>"></script>
<?php echo $GoogleAnalytics; ?>
<style>
    
    /* Custom styles for the dropdown background */
.custom-dropdown {
    background-color: #000; /* Black background */
    color: #fff; /* White text */
    border: 1px solid #333; /* Optional: add a border with a darker color for better contrast */
}

/* Change the background of the options inside the dropdown */
.custom-dropdown option {
    background-color: #000; /* Black background for options */
    color: #fff; /* White text for options */
}

/* Optional: Change the focus/hover styles */
.custom-dropdown:focus, .custom-dropdown:hover {
    background-color: #333; /* Darker background when focused or hovered */
    border-color: #555; /* Darker border on focus */
}

.navigation-links {
    display: flex;
    justify-content: center; /* Center the links horizontally */
    gap: 20px; /* Add spacing between the links */
    margin: 20px 0; /* Optional: Add vertical spacing */
}

.navigation-links a {
    text-decoration: none; /* Remove underline from links */
    color: #fff; /* Set link color */
    font-size: 16px; /* Adjust font size */
    font-weight: bold; /* Make the text bold */
}

.navigation-links a:hover {
    color: #ffbade; /* Optional: Change color on hover */
}


</style>
</head>
<body>
<div class="main-container">
<header id="hd" class="hd" itemscope="" itemtype="http://schema.org/WPHeader">
<div class="cent">
<button type="button" class="bta btaa">
<i>
</i>
</button>
<figure class="logo fg1">
<div itemscope="itemscope" itemtype="http://schema.org/Brand" class="d-flex">
<a itemprop="url" href="/">
<img itemprop="logo" src="/img/logo.png?v=<?php echo $v; ?>" title="<?php echo $Title; ?> - Stream Anime Sub or Dub in High Quality up to 1080p" alt="<?php echo $Title; ?> - Stream Anime Sub or Dub in High Quality up to 1080p">
</a>
<div class="menu-header-alt cny">
<?php include('menu.php'); ?>
</nav>
</div>
</header>
<div class="container amx asn">
<div class="bod">
<div class="theatre">
<div class="breadcrumb" itemscope="" itemtype="https://schema.org/BreadcrumbList">
<span class="breadcrumb-link-wrap" itemprop="itemListElement" itemscope="" itemtype="https://schema.org/ListItem">
<a class="breadcrumb-link" href="/" itemprop="item">
<span class="breadcrumb-link-text-wrap" itemprop="name"><?php echo $Title; ?>
</span>
</a>
</span>
<span aria-label="breadcrumb separator"> /
</span>
<a href="/anime/<?php echo $data['animeid']; ?>"> <?php echo unslug($data['animeid']); ?></a>
<span aria-label="breadcrumb separator"> /
</span> <?php echo unslug($animeid);?> Episode <?php echo $episode;?>
</div>
<?php
                            // Function to fetch the API data
                            function fetchApiData($apiBase, $animeid, $episode,$apiKey) {
                                $url = "$apiBase/api/watch/{$animeid}-episode-{$episode}?api_key=$apiKey";
                                $response = @file_get_contents($url); // Suppress errors
                                if ($response === false) {
                                    return null; // Return null if API request fails
                                }
                                $data = json_decode($response, true);
                                return is_array($data) ? $data : null; // Ensure data is an array
                            }
                            
                            $data = fetchApiData($apiBase, $animeid, $episode,$apiKey);
                            
                            // Check if data is valid
                            if (!$data) {
                                echo "<p>Episode not available.</p>"; // Display an error message if no data is found
                                exit;
                            }
                            
                            // Select the default subtitle (or dub) source
                            $defaultSource = isset($data['sub'][0]) ? $data['sub'][0] : (isset($data['dub'][0]) ? $data['dub'][0] : null);
                            if (!$defaultSource) {
                                echo "<p>Default source not available.</p>"; // Show an error if no valid source is found
                                exit;
                            }
                            ?>
							<?php
                                // Always use the default streaming link
                                $iframeSrc = "https://hianime.ws/v.php?animeid={$animeid}-episode-{$episode}";
                                ?>
<div class="theatre-settings">
<div id="video" class="player iframe video-js vjs-default-skin vjs-skin-flat-grey vjs-big-play-centered vjs-16-9 vidstreaming_iframe">
 <?php
                                // Always use the default streaming link
                                $iframeSrc = "https://hianime.ws/v.php?animeid={$animeid}-episode-{$episode}";
                                ?>
                                <iframe id="video-frame" src="<?= $iframeSrc ?>" allow="fullscreen" allowfullscreen="yes" frameborder="no" scrolling="no" style="width: 100%; height: 100%; overflow: hidden;"></iframe>
</div>
<div class="row flex">
<div class="col-sm-3">

</div>



<!-- Dropdown for selecting server -->
<div class="col-sm-3">
    <div class="dropup" id="hostitem">
       <select id="server-select" name="select-episodse" class="btn btn-secondary btn-block dropdown-toggle custom-dropdown">
                                        <!-- Always add the default streaming option -->
										<?php if (!empty($data['sub'])): ?>
                                        <option class='server-li' value='https://hianime.ws/v.php?animeid=<?=$animeid?>-episode-<?=$episode?>'>HD-1 Sub</option>
										 <?php endif; ?>
                                        <?php if (!empty($data['dub'])): ?>
                                        <option class='server-li' value='https://hianime.ws/v.php?animeid=<?=$animeid?>-dub-episode-<?=$episode?>'>HD-1 Dub</option>
										<?php endif; ?>
                            
                                        <?php
                                        // Loop through the servers (subtitles and dubs)
                                        foreach (['sub', 'dub'] as $type) {
                                            foreach ($data[$type] as $source) {
                                                // Skip 'sub_url' and 'dub_url' sources
                                                if (strpos($source['sources_name'], 'url') !== false) {
                                                    continue; // Skip this source
                                                }
                            
                                                $typeLabel = ($type == 'sub') ? 'Sub' : 'Dub'; // Display Sub or Dub
                                                echo "<option class='server-li' value='" . htmlspecialchars($source['sources_link']) . "'>" . htmlspecialchars($source['sources_name']) . " ($typeLabel)</option>";
                                            }
                                        }
                                        ?>
                                    </select>
    </div>
</div>
<script>
                            // JavaScript to switch iframe source when server is selected
                            document.getElementById('server-select').addEventListener('change', function() {
                                var iframe = document.getElementById('video-frame');
                                var selectedSource = this.value; // Get the selected server link
                                iframe.src = selectedSource; // Change the iframe source
                            });
                            </script>
        
</div>
</div>
</div>


<?php
				// Fetch API details for the anime 
				$anime_details_url = "$apiBase/api/details/$animeid?api_key=$apiKey";

				// Function to fetch data from the API
				function fetchAPI($url) {
					$ch = curl_init();
					curl_setopt($ch, CURLOPT_URL, $url);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
					curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
					$response = curl_exec($ch);
					curl_close($ch);
					return json_decode($response, true);
				}

				// Get anime details and episodes
				$anime_details = fetchAPI($anime_details_url);

				?>
<center>
    <a href="https://codyphp.com" target="_blank" rel="noopener noreferrer">
        <img src="https://i.ibb.co/KFHbyKC/Looking-for-Streaming-Script.gif" alt="Anime Streaming Script">
    </a>
</center>

<div class="entry-content">
<img width="375" height="500" class="attachment-post-thumbnail size-post-thumbnail wp-post-image lazy" src="https://cdn.okarun.ws<?php echo $anime_details['image'];?>" alt="<?php echo $anime_details['title'];?>">
<h2><?php echo unslug($animeid);?> Episode <?php echo $episode;?>
</h2>
<h4>Episode Lists
</h4> :
<i>
<a href="/anime/<?php echo $animeid;?>"> <?php echo $anime_details['title'];?>
</a>
</i>
<br>
<h4>Synonyms
</h4> :
<i>
<span>
<span>
</span>
<span><?php echo $anime_details['titlejp'];?>
</span>
</span>
<span>
</span>
</span>
<span>
</span>
</i>
<br>
<div class="clear">
</div>
<h3 class="info-main">Storyline Synopsis
</h3>
<p class="card-textu"><?php echo $anime_details['description'];?>
</p>
<h3 class="info-main"> Series
</h3>
<p class="card-textu">Watch <?php echo unslug($animeid);?> Episode <?php echo $episode;?> on <?php echo $Title; ?>. You can also download free <?php echo unslug($animeid);?> Episode <?php echo $episode;?>, don't forget to watch online streaming of various quality 720P 360P 240P 480P according to your connection to save internet quota, <?php echo unslug($animeid);?> Episode <?php echo $episode;?> on <?php echo $Title; ?> MP4 MKV hardsub softsub English subbed is already contained in the video.
</p>
</div>
<div class="costr foregrounda">
    <span class="name">Comments</span>
    <span class="line"></span>
</div>

<div id="disqus_thread"></div>
<script>
     var site_config = {
    'domain': '<?php echo $DisqusDomain; ?>',
    'disqus': '<?php echo $DisqusShort; ?>', // Make sure this matches your Disqus shortname
	};

	// Dynamically load Disqus
	(function() {
		var d = document, s = d.createElement('script');
		s.src = 'https://' + site_config.disqus + '.disqus.com/embed.js';
		s.setAttribute('data-timestamp', +new Date());
		(d.head || d.body).appendChild(s);
	})();

</script>

</div>
</div>





<footer class="ft">
<div class="cont">
<nav>
<?php include('footurl.php'); ?>
<p class="copy tac">Copyright © <?php echo $Title; ?>. All Rights Reserved
</p>
</nav>
</div>
</footer>

</body>
</html>
